@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "2.36";
+our $VERSION = "2.37";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -794,8 +794,9 @@ sub version {
 
 # don't forget to update POD
 my @commands = qw(
-  append	auth	bgrewriteaof	bgsave	bitcount	bitop	bitpos
+  append	asking	auth	bgrewriteaof	bgsave	bitcount	bitop	bitpos
   blpop	brpop   brpoplpush	client	client_kill	client_getname	client_setname
+  cluster	cluster_slots
   config	config_get	config_set	config_resetstat	config_rewrite
   dbsize	debug_error	debug_object	debug_segfault
   decr	decrby	del	dump	echo	eval    evalsha exists	expire	expireat	flushall
@@ -840,9 +841,9 @@ I<execute>, waits for the reply from the server, and returns it. E.g.:
     # equivalent to
     $redis->send_command("get", $key, sub { $val = $_[1] });
 
-The following wrapper methods are defined: append, auth, bgrewriteaof, bgsave,
+The following wrapper methods are defined: append, asking, auth, bgrewriteaof, bgsave,
 bitcount, bitop, bitpos, blpop, brpop, brpoplpush, client, client_kill,
-client_getname, client_setname, config, config_get, config_set,
+client_getname, client_setname, cluster, cluster_slots, config, config_get, config_set,
 config_resetstat, config_rewrite, dbsize, debug_error, debug_object, debug_segfault, decr,
 decrby, del, dump, echo, eval, evalsha, exists, expire, expireat, flushall,
 flushdb, get, getbit, getrange, getset, hdel, hexists, hget, hgetall, hincrby,
@@ -952,6 +953,30 @@ sub _parse_client_list {
     return $res;
 }
 
+sub cluster_nodes {
+    my $self = shift;
+    my $list = $self->execute(qw(CLUSTER NODES));
+    my @nodes;
+    for ( split /^/, $list ) {
+        my ( $node_id, $addr, @rest ) = split / /;
+        my %flags;
+        while ( ( my $flag = shift @rest ) ne '-' ) {
+            $flags{$flag} = 1;
+        }
+        my $node = {
+            node_id            => $node_id,
+            address            => $addr,
+            flags              => \%flags,
+            last_ping_sent     => $rest[0],
+            last_pong_received => $rest[1],
+            link_state         => $rest[2],
+            slots              => $rest[3],
+        };
+        push @nodes, $node;
+    }
+    return \@nodes;
+}
+
 =head2 $self->shutdown
 
 Shuts the redis server down. Returns undef, as the server doesn't send the
@@ -1604,7 +1629,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2014 Pavel Shaydo.
+Copyright 2011-2015 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
